@@ -4,27 +4,28 @@ Copyright 2021-2021 The jdh99 Authors. All rights reserved.
 Authors: jdh99 <jdh821@163.com>
 """
 
-import utzpy.nlv1 as nlv1
-
 import unittest
 
+# IA地址字节数
+IA_LEN = 8
+
 
 def bytes_to_ia(data: bytearray) -> int:
     """从字节流中取出IA地址.字节流是大端"""
-    if len(data) < nlv1.IA_LEN:
+    if len(data) < IA_LEN:
         return 0
 
     ia = 0
-    for i in range(nlv1.IA_LEN):
-        ia += data[i] << ((nlv1.IA_LEN - 1 - i) << 3)
+    for i in range(IA_LEN):
+        ia += data[i] << ((IA_LEN - 1 - i) << 3)
     return ia
 
 
 def ia_to_bytes(ia: int) -> bytearray:
     """将IA地址转换为字节流.字节流是大端"""
     data = bytearray()
-    for i in range(nlv1.IA_LEN):
-        data.append((ia >> ((nlv1.IA_LEN - 1 - i) << 3)) & 0xff)
+    for i in range(IA_LEN):
+        data.append((ia >> ((IA_LEN - 1 - i) << 3)) & 0xff)
     return data
 
 
